Enumeration

VipsAccess

since: 8.0

Declaration

enum Vips.Access

Description [src]

The type of access an operation has to supply. See vips_tilecache() and VipsForeign.

VipsAccess means requests can come in any order.

VipsAccess means requests will be top-to-bottom, but with some amount of buffering behind the read point for small non-local accesses.

Available since: 8.0

Members

VIPS_ACCESS_RANDOM

Can read anywhere.

  • Value: 0
  • Nickname: random
  • Available since: 8.0
VIPS_ACCESS_SEQUENTIAL

Top-to-bottom reading only, but with a small buffer.

  • Value: 1
  • Nickname: sequential
  • Available since: 8.0
VIPS_ACCESS_SEQUENTIAL_UNBUFFERED
No description available.
  • Value: 2
  • Nickname: sequential-unbuffered
  • Available since: 8.0
VIPS_ACCESS_LAST
No description available.
  • Value: 3
  • Nickname: last
  • Available since: 8.0