Enumeration

VipsBandFormat

since: 8.0

Declaration

enum Vips.BandFormat

Description [src]

The format used for each band element.

Each corresponds to a native C type for the current machine. For example, VipsBandFormat is unsigned short.

Available since: 8.0

Members

VIPS_FORMAT_NOTSET

Invalid setting.

  • Value: -1
  • Nickname: notset
  • Available since: 8.0
VIPS_FORMAT_UCHAR

Unsigned char format.

  • Value: 0
  • Nickname: uchar
  • Available since: 8.0
VIPS_FORMAT_CHAR

Char format.

  • Value: 1
  • Nickname: char
  • Available since: 8.0
VIPS_FORMAT_USHORT

Unsigned short format.

  • Value: 2
  • Nickname: ushort
  • Available since: 8.0
VIPS_FORMAT_SHORT

Short format.

  • Value: 3
  • Nickname: short
  • Available since: 8.0
VIPS_FORMAT_UINT

Unsigned int format.

  • Value: 4
  • Nickname: uint
  • Available since: 8.0
VIPS_FORMAT_INT

Int format.

  • Value: 5
  • Nickname: int
  • Available since: 8.0
VIPS_FORMAT_FLOAT

Float format.

  • Value: 6
  • Nickname: float
  • Available since: 8.0
VIPS_FORMAT_COMPLEX

Complex (two floats) format.

  • Value: 7
  • Nickname: complex
  • Available since: 8.0
VIPS_FORMAT_DOUBLE

Double float format.

  • Value: 8
  • Nickname: double
  • Available since: 8.0
VIPS_FORMAT_DPCOMPLEX

Double complex (two double) format.

  • Value: 9
  • Nickname: dpcomplex
  • Available since: 8.0
VIPS_FORMAT_LAST
No description available.
  • Value: 10
  • Nickname: last
  • Available since: 8.0

Type functions

vips_band_format_is8bit

Return TRUE if format is uchar or schar.

since: 8.0

vips_band_format_iscomplex

Return TRUE if fmt is one of the complex types.

since: 8.0

vips_band_format_isfloat

Return TRUE if format is one of the float types.

since: 8.0

vips_band_format_isint

Return TRUE if format is one of the integer types.

since: 8.0

vips_band_format_isuint

Return TRUE if format is one of the unsigned integer types.

since: 8.0