Enumeration
VipsBlendMode
since: 8.0
Description [src]
The various Porter-Duff and PDF blend modes. See vips_composite(),
for example.
The Cairo docs have a nice explanation of all the blend modes.
The non-separable modes are not implemented.
Available since: 8.0
Members
VIPS_BLEND_MODE_CLEAR-
Where the second object is drawn, the first is removed.
- Value:
0 - Nickname:
clear - Available since: 8.0
- Value:
VIPS_BLEND_MODE_SOURCE-
The second object is drawn as if nothing were below.
- Value:
1 - Nickname:
source - Available since: 8.0
- Value:
VIPS_BLEND_MODE_OVER-
The image shows what you would expect if you held two semi-transparent slides on top of each other.
- Value:
2 - Nickname:
over - Available since: 8.0
- Value:
VIPS_BLEND_MODE_IN-
The first object is removed completely, the second is only drawn where the first was.
- Value:
3 - Nickname:
in - Available since: 8.0
- Value:
VIPS_BLEND_MODE_OUT-
The second is drawn only where the first isn’t.
- Value:
4 - Nickname:
out - Available since: 8.0
- Value:
VIPS_BLEND_MODE_ATOP-
This leaves the first object mostly intact, but mixes both objects in the overlapping area.
- Value:
5 - Nickname:
atop - Available since: 8.0
- Value:
VIPS_BLEND_MODE_DEST-
Leaves the first object untouched, the second is discarded completely.
- Value:
6 - Nickname:
dest - Available since: 8.0
- Value:
VIPS_BLEND_MODE_DEST_OVER-
Like OVER, but swaps the arguments.
- Value:
7 - Nickname:
dest-over - Available since: 8.0
- Value:
VIPS_BLEND_MODE_DEST_IN-
Like IN, but swaps the arguments.
- Value:
8 - Nickname:
dest-in - Available since: 8.0
- Value:
VIPS_BLEND_MODE_DEST_OUT-
Like OUT, but swaps the arguments.
- Value:
9 - Nickname:
dest-out - Available since: 8.0
- Value:
VIPS_BLEND_MODE_DEST_ATOP-
Like ATOP, but swaps the arguments.
- Value:
10 - Nickname:
dest-atop - Available since: 8.0
- Value:
VIPS_BLEND_MODE_XOR-
Something like a difference operator.
- Value:
11 - Nickname:
xor - Available since: 8.0
- Value:
VIPS_BLEND_MODE_ADD-
A bit like adding the two images.
- Value:
12 - Nickname:
add - Available since: 8.0
- Value:
VIPS_BLEND_MODE_SATURATE-
A bit like the darker of the two.
- Value:
13 - Nickname:
saturate - Available since: 8.0
- Value:
VIPS_BLEND_MODE_MULTIPLY-
At least as dark as the darker of the two inputs.
- Value:
14 - Nickname:
multiply - Available since: 8.0
- Value:
VIPS_BLEND_MODE_SCREEN-
At least as light as the lighter of the inputs.
- Value:
15 - Nickname:
screen - Available since: 8.0
- Value:
VIPS_BLEND_MODE_OVERLAY-
Multiplies or screens colors, depending on the lightness.
- Value:
16 - Nickname:
overlay - Available since: 8.0
- Value:
VIPS_BLEND_MODE_DARKEN-
The darker of each component.
- Value:
17 - Nickname:
darken - Available since: 8.0
- Value:
VIPS_BLEND_MODE_LIGHTEN-
The lighter of each component.
- Value:
18 - Nickname:
lighten - Available since: 8.0
- Value:
VIPS_BLEND_MODE_COLOUR_DODGE-
Brighten first by a factor second.
- Value:
19 - Nickname:
colour-dodge - Available since: 8.0
- Value:
VIPS_BLEND_MODE_COLOUR_BURN-
Darken first by a factor of second.
- Value:
20 - Nickname:
colour-burn - Available since: 8.0
- Value:
VIPS_BLEND_MODE_HARD_LIGHT-
Multiply or screen, depending on lightness.
- Value:
21 - Nickname:
hard-light - Available since: 8.0
- Value:
VIPS_BLEND_MODE_SOFT_LIGHT-
Darken or lighten, depending on lightness.
- Value:
22 - Nickname:
soft-light - Available since: 8.0
- Value:
VIPS_BLEND_MODE_DIFFERENCE-
Difference of the two.
- Value:
23 - Nickname:
difference - Available since: 8.0
- Value:
VIPS_BLEND_MODE_EXCLUSION-
Somewhat like DIFFERENCE, but lower-contrast.
- Value:
24 - Nickname:
exclusion - Available since: 8.0
- Value:
VIPS_BLEND_MODE_LAST-
No description available.
- Value:
25 - Nickname:
last - Available since: 8.0
- Value: