Enumeration
VipsExtend
since: 8.0
Description [src]
See vips_embed(), vips_conv(), vips_affine() and so on.
When the edges of an image are extended, you can specify how you want the extension done.
VipsExtend — new pixels are black, ie. all bits are zero.
VipsExtend — each new pixel takes the value of the nearest edge pixel
VipsExtend — the image is tiled to fill the new area
VipsExtend — the image is reflected and tiled to reduce hash edges
VipsExtend — new pixels are white, ie. all bits are set
VipsExtend — colour set from the background property
We have to specify the exact value of each enum member since we have to keep these frozen for back compat with vips7.
See also
Available since: 8.0
Members
VIPS_EXTEND_BLACK-
Extend with black (all 0) pixels.
- Value:
0 - Nickname:
black - Available since: 8.0
- Value:
VIPS_EXTEND_COPY-
Copy the image edges.
- Value:
1 - Nickname:
copy - Available since: 8.0
- Value:
VIPS_EXTEND_REPEAT-
Repeat the whole image.
- Value:
2 - Nickname:
repeat - Available since: 8.0
- Value:
VIPS_EXTEND_MIRROR-
Mirror the whole image.
- Value:
3 - Nickname:
mirror - Available since: 8.0
- Value:
VIPS_EXTEND_WHITE-
Extend with white (all bits set) pixels.
- Value:
4 - Nickname:
white - Available since: 8.0
- Value:
VIPS_EXTEND_BACKGROUND-
Extend with colour from the
backgroundproperty.- Value:
5 - Nickname:
background - Available since: 8.0
- Value:
VIPS_EXTEND_LAST-
No description available.
- Value:
6 - Nickname:
last - Available since: 8.0
- Value: