Enumeration

VipsFailOn

since: 8.0

Declaration

enum Vips.FailOn

Description [src]

How sensitive loaders are to errors, from never stop (very insensitive), to stop on the smallest warning (very sensitive).

Each one implies the ones before it, so VipsFailOn implies VipsFailOn.

Available since: 8.0

Members

VIPS_FAIL_ON_NONE

Never stop.

  • Value: 0
  • Nickname: none
  • Available since: 8.0
VIPS_FAIL_ON_TRUNCATED

Stop on image truncated, nothing else.

  • Value: 1
  • Nickname: truncated
  • Available since: 8.0
VIPS_FAIL_ON_ERROR

Stop on serious error or truncation.

  • Value: 2
  • Nickname: error
  • Available since: 8.0
VIPS_FAIL_ON_WARNING

Stop on anything, even warnings.

  • Value: 3
  • Nickname: warning
  • Available since: 8.0
VIPS_FAIL_ON_LAST
No description available.
  • Value: 4
  • Nickname: last
  • Available since: 8.0