Enumeration

VipsForeignHeifEncoder

since: 8.0

Declaration

enum Vips.ForeignHeifEncoder

Description [src]

The selected encoder to use. If libheif hasn’t been compiled with the selected encoder, we will fallback to the default encoder for the compression format.

Available since: 8.0

Members

VIPS_FOREIGN_HEIF_ENCODER_AUTO

Auto.

  • Value: 0
  • Nickname: auto
  • Available since: 8.0
VIPS_FOREIGN_HEIF_ENCODER_AOM

Aom.

  • Value: 1
  • Nickname: aom
  • Available since: 8.0
VIPS_FOREIGN_HEIF_ENCODER_RAV1E

RAV1E.

  • Value: 2
  • Nickname: rav1e
  • Available since: 8.0
VIPS_FOREIGN_HEIF_ENCODER_SVT

SVT-AV1

  • Value: 3
  • Nickname: svt
  • Available since: 8.0
VIPS_FOREIGN_HEIF_ENCODER_X265

X265

  • Value: 4
  • Nickname: x265
  • Available since: 8.0
VIPS_FOREIGN_HEIF_ENCODER_LAST
No description available.
  • Value: 5
  • Nickname: last
  • Available since: 8.0