Struct

VipsArea

since: 8.0

Description

struct VipsArea {
  void* data;
  size_t length;
  int n;
}
No description available.
Structure members
data
No description available.
length
No description available.
n
No description available.

Available since: 8.0

Constructors

vips_area_new

A VipsArea wraps a chunk of memory. It adds reference counting and a free function. It also keeps a count and a GType, so the area can be an array.

since: 8.0

vips_area_new_array

An area which holds an array of elements of some GType. To set values for the elements, get the pointer and write.

since: 8.0

vips_area_new_array_object

An area which holds an array of GObject s. See vips_area_new_array(). When the area is freed, each GObject will be unreffed.

since: 8.0

Functions

vips_area_free_cb
No description available.

since: 8.0

Instance methods

vips_area_copy
No description available.

since: 8.0

vips_area_get_data

Return the data pointer plus optionally the length in bytes of an area, the number of elements, the GType of each element and the sizeof() each element.

since: 8.0

vips_area_unref
No description available.

since: 8.0