Struct
VipsArgument
since: 8.0
Description [src]
struct VipsArgument {
GParamSpec* pspec;
}
Libvips has a simple mechanism for automating at least some aspects of
GObject properties. You add a set of macros to your
_class_init() which describe the arguments, and set the get and set
functions to the libvips ones.
See extending for a complete example.
Structure members
pspec- No description available.
Available since: 8.0
Functions
vips_argument_map
Loop over the VipsArgument of an object. Stop when fn returns non-NULL
and return that value.
since: 8.0