Struct
VipsArrayDouble
since: 8.0
Constructors
vips_array_double_new
Allocate a new array of doubles and copy array into it. Free with
vips_area_unref().
since: 8.0
vips_array_double_newv
Allocate a new array of n doubles and copy @… into it. Free with
vips_area_unref().
since: 8.0
Instance methods
vips_array_double_get
Fetch a double array from a VipsArrayDouble. Useful for language bindings.
since: 8.0