Struct

VipsArrayInt

since: 8.0

Description

struct VipsArrayInt {
  VipsArea area;
}
No description available.
Structure members
area
No description available.

Available since: 8.0

Constructors

vips_array_int_new

Allocate a new array of ints and copy array into it. Free with vips_area_unref().

since: 8.0

vips_array_int_newv

Allocate a new array of n ints and copy @… into it. Free with vips_area_unref().

since: 8.0

Instance methods

vips_array_int_get

Fetch an int array from a VipsArrayInt. Useful for language bindings.

since: 8.0