Struct
VipsDbuf
since: 8.0
Instance methods
vips_dbuf_allocate
Make sure dbuf has at least size bytes available after the write point.
since: 8.0
vips_dbuf_destroy
Destroy dbuf. This frees any allocated memory. Useful for dbufs on the stack.
since: 8.0
vips_dbuf_get_write
Return a pointer to an area you can write to, return length of area in
size. Use vips_dbuf_allocate() before this call to set a minimum amount of
space to have available.
since: 8.0
vips_dbuf_read
Up to size bytes are read from the buffer and copied to data. The number
of bytes transferred is returned.
since: 8.0
vips_dbuf_reset
Reset the buffer to empty. No memory is freed, just the data size and write point are reset.
since: 8.0
vips_dbuf_seek
Move the write point. whence can be SEEK_SET, SEEK_CUR, SEEK_END, with
the usual meaning.
since: 8.0
vips_dbuf_steal
Destroy a buffer, but rather than freeing memory, a pointer is returned.
This must be freed with g_free().
since: 8.0
vips_dbuf_truncate
Truncate the data so that it ends at the write point. No memory is freed.
since: 8.0
vips_dbuf_write_amp
Write str to dbuf, but escape stuff that xml hates in text. Our
argument string is utf-8.
since: 8.0