Enumeration
VipsInteresting
since: 8.0
Description [src]
Pick the algorithm vips uses to decide image “interestingness”. This is used
by vips_smartcrop(), for example, to decide what parts of the image to keep.
VipsInteresting and VipsInteresting mean the same — the
crop is positioned at the top or left. VipsInteresting positions at
the bottom or right.
See also
Available since: 8.0
Members
VIPS_INTERESTING_NONE-
Do nothing.
- Value:
0 - Nickname:
none - Available since: 8.0
- Value:
VIPS_INTERESTING_CENTRE-
Just take the centre.
- Value:
1 - Nickname:
centre - Available since: 8.0
- Value:
VIPS_INTERESTING_ENTROPY-
Use an entropy measure.
- Value:
2 - Nickname:
entropy - Available since: 8.0
- Value:
VIPS_INTERESTING_ATTENTION-
Look for features likely to draw human attention.
- Value:
3 - Nickname:
attention - Available since: 8.0
- Value:
VIPS_INTERESTING_LOW-
Position the crop towards the low coordinate.
- Value:
4 - Nickname:
low - Available since: 8.0
- Value:
VIPS_INTERESTING_HIGH-
Position the crop towards the high coordinate.
- Value:
5 - Nickname:
high - Available since: 8.0
- Value:
VIPS_INTERESTING_ALL-
Everything is interesting.
- Value:
6 - Nickname:
all - Available since: 8.0
- Value:
VIPS_INTERESTING_LAST-
No description available.
- Value:
7 - Nickname:
last - Available since: 8.0
- Value: